==> jc-1.4.0.tar.gz: java/lang/annotation/AnnotationTypeMismatchException.h <==
// public class java.lang.annotation.AnnotationTypeMismatchException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class ceb073224be6f0a4 java_lang_annotation_AnnotationTypeMismatchException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_java_lang_annotation_AnnotationTypeMismatchException_H_
#define _JC_java_lang_annotation_AnnotationTypeMismatchException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_reflect_Method$object;

// Typedefs
typedef struct _jc_java_lang_annotation_AnnotationTypeMismatchException$sub_refs	_jc_java_lang_annotation_AnnotationTypeMismatchException$sub_refs;
typedef struct _jc_java_lang_annotation_AnnotationTypeMismatchException$sub_nonrefs	_jc_java_lang_annotation_AnnotationTypeMismatchException$sub_nonrefs;
typedef struct _jc_java_lang_annotation_AnnotationTypeMismatchException$refs	_jc_java_lang_annotation_AnnotationTypeMismatchException$refs;
typedef struct _jc_java_lang_annotation_AnnotationTypeMismatchException$nonrefs	_jc_java_lang_annotation_AnnotationTypeMismatchException$nonrefs;
typedef struct _jc_java_lang_annotation_AnnotationTypeMismatchException$object	_jc_java_lang_annotation_AnnotationTypeMismatchException$object;

typedef struct _jc_java_lang_annotation_AnnotationTypeMismatchException$fields_struct	_jc_java_lang_annotation_AnnotationTypeMismatchException$fields_struct;
typedef const struct _jc_java_lang_annotation_AnnotationTypeMismatchException$vmethods	_jc_java_lang_annotation_AnnotationTypeMismatchException$vmethods;
typedef const struct _jc_java_lang_annotation_AnnotationTypeMismatchException$vtable	_jc_java_lang_annotation_AnnotationTypeMismatchException$vtable;
typedef const struct _jc_java_lang_annotation_AnnotationTypeMismatchException$vtype	_jc_java_lang_annotation_AnnotationTypeMismatchException$vtype;

// Class fields structure
struct _jc_java_lang_annotation_AnnotationTypeMismatchException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_annotation_AnnotationTypeMismatchException$fields_struct _jc_java_lang_annotation_AnnotationTypeMismatchException$class_fields;

// Constructors
extern void _jc_java_lang_annotation_AnnotationTypeMismatchException$method$_init$59eebd79bd41192f(_jc_env *, struct _jc_java_lang_annotation_AnnotationTypeMismatchException$object *, struct _jc_java_lang_reflect_Method$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_reflect_Method$object *_jc_java_lang_annotation_AnnotationTypeMismatchException$method$element$bfe9964cdff5e259(_jc_env *, struct _jc_java_lang_annotation_AnnotationTypeMismatchException$object *);
extern struct _jc_java_lang_String$object *_jc_java_lang_annotation_AnnotationTypeMismatchException$method$foundType$6a427cc90971aa7e(_jc_env *, struct _jc_java_lang_annotation_AnnotationTypeMismatchException$object *);

// Virtual method descriptors
extern _jc_method _jc_java_lang_annotation_AnnotationTypeMismatchException$method_info$element$bfe9964cdff5e259;
extern _jc_method _jc_java_lang_annotation_AnnotationTypeMismatchException$method_info$foundType$6a427cc90971aa7e;

// Virtual methods structure
struct _jc_java_lang_annotation_AnnotationTypeMismatchException$vmethods {
	struct _jc_java_lang_reflect_Method$object	*(*element$bfe9964cdff5e259)(_jc_env *, struct _jc_java_lang_annotation_AnnotationTypeMismatchException$object *);
	struct _jc_java_lang_String$object	*(*foundType$6a427cc90971aa7e)(_jc_env *, struct _jc_java_lang_annotation_AnnotationTypeMismatchException$object *);
};

// Vtable
struct _jc_java_lang_annotation_AnnotationTypeMismatchException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_annotation_AnnotationTypeMismatchException$vmethods	java_lang_annotation_AnnotationTypeMismatchException;
};

// Vtype
struct _jc_java_lang_annotation_AnnotationTypeMismatchException$vtype {
	_jc_type			type;
	_jc_java_lang_annotation_AnnotationTypeMismatchException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_annotation_AnnotationTypeMismatchException$sub_refs {
	struct _jc_java_lang_reflect_Method$object	*element;
	struct _jc_java_lang_String$object	*foundType;
};

// Reference instance fields (object)
struct _jc_java_lang_annotation_AnnotationTypeMismatchException$refs {
    _jc_java_lang_annotation_AnnotationTypeMismatchException$sub_refs	java_lang_annotation_AnnotationTypeMismatchException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_annotation_AnnotationTypeMismatchException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_annotation_AnnotationTypeMismatchException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_annotation_AnnotationTypeMismatchException$sub_nonrefs	java_lang_annotation_AnnotationTypeMismatchException;
};

// Object instance structure
struct _jc_java_lang_annotation_AnnotationTypeMismatchException$object {
	_jc_java_lang_annotation_AnnotationTypeMismatchException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_annotation_AnnotationTypeMismatchException$vtype	*vtype;
	_jc_java_lang_annotation_AnnotationTypeMismatchException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_annotation_AnnotationTypeMismatchException$vtype _jc_java_lang_annotation_AnnotationTypeMismatchException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_annotation_AnnotationTypeMismatchException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_annotation_AnnotationTypeMismatchException$class_object;

#endif	/* _JC_java_lang_annotation_AnnotationTypeMismatchException_H_ */

==> jc-1.4.6.tar.gz: java/lang/annotation/AnnotationTypeMismatchException.h <==
// public class java.lang.annotation.AnnotationTypeMismatchException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class ceb073224be6f0a4 java_lang_annotation_AnnotationTypeMismatchException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_java_lang_annotation_AnnotationTypeMismatchException_H_
#define _JC_java_lang_annotation_AnnotationTypeMismatchException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_reflect_Method$object;

// Typedefs
typedef struct _jc_java_lang_annotation_AnnotationTypeMismatchException$sub_refs	_jc_java_lang_annotation_AnnotationTypeMismatchException$sub_refs;
typedef struct _jc_java_lang_annotation_AnnotationTypeMismatchException$sub_nonrefs	_jc_java_lang_annotation_AnnotationTypeMismatchException$sub_nonrefs;
typedef struct _jc_java_lang_annotation_AnnotationTypeMismatchException$refs	_jc_java_lang_annotation_AnnotationTypeMismatchException$refs;
typedef struct _jc_java_lang_annotation_AnnotationTypeMismatchException$nonrefs	_jc_java_lang_annotation_AnnotationTypeMismatchException$nonrefs;
typedef struct _jc_java_lang_annotation_AnnotationTypeMismatchException$object	_jc_java_lang_annotation_AnnotationTypeMismatchException$object;

typedef struct _jc_java_lang_annotation_AnnotationTypeMismatchException$fields_struct	_jc_java_lang_annotation_AnnotationTypeMismatchException$fields_struct;
typedef const struct _jc_java_lang_annotation_AnnotationTypeMismatchException$vmethods	_jc_java_lang_annotation_AnnotationTypeMismatchException$vmethods;
typedef const struct _jc_java_lang_annotation_AnnotationTypeMismatchException$vtable	_jc_java_lang_annotation_AnnotationTypeMismatchException$vtable;
typedef const struct _jc_java_lang_annotation_AnnotationTypeMismatchException$vtype	_jc_java_lang_annotation_AnnotationTypeMismatchException$vtype;

// Class fields structure
struct _jc_java_lang_annotation_AnnotationTypeMismatchException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_annotation_AnnotationTypeMismatchException$fields_struct _jc_java_lang_annotation_AnnotationTypeMismatchException$class_fields;

// Constructors
extern void _jc_java_lang_annotation_AnnotationTypeMismatchException$method$_init$59eebd79bd41192f(_jc_env *, struct _jc_java_lang_annotation_AnnotationTypeMismatchException$object *, struct _jc_java_lang_reflect_Method$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_reflect_Method$object *_jc_java_lang_annotation_AnnotationTypeMismatchException$method$element$bfe9964cdff5e259(_jc_env *, struct _jc_java_lang_annotation_AnnotationTypeMismatchException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_lang_annotation_AnnotationTypeMismatchException$method$foundType$6a427cc90971aa7e(_jc_env *, struct _jc_java_lang_annotation_AnnotationTypeMismatchException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_lang_annotation_AnnotationTypeMismatchException$method_info$element$bfe9964cdff5e259;
extern _jc_method _jc_java_lang_annotation_AnnotationTypeMismatchException$method_info$foundType$6a427cc90971aa7e;

// Virtual methods structure
struct _jc_java_lang_annotation_AnnotationTypeMismatchException$vmethods {
	struct _jc_java_lang_reflect_Method$object	*(*element$bfe9964cdff5e259)(_jc_env *, struct _jc_java_lang_annotation_AnnotationTypeMismatchException$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*foundType$6a427cc90971aa7e)(_jc_env *, struct _jc_java_lang_annotation_AnnotationTypeMismatchException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_lang_annotation_AnnotationTypeMismatchException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_annotation_AnnotationTypeMismatchException$vmethods	java_lang_annotation_AnnotationTypeMismatchException;
};

// Vtype
struct _jc_java_lang_annotation_AnnotationTypeMismatchException$vtype {
	_jc_type			type;
	_jc_java_lang_annotation_AnnotationTypeMismatchException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_annotation_AnnotationTypeMismatchException$sub_refs {
	struct _jc_java_lang_reflect_Method$object	*element;
	struct _jc_java_lang_String$object	*foundType;
};

// Reference instance fields (object)
struct _jc_java_lang_annotation_AnnotationTypeMismatchException$refs {
    _jc_java_lang_annotation_AnnotationTypeMismatchException$sub_refs	java_lang_annotation_AnnotationTypeMismatchException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_annotation_AnnotationTypeMismatchException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_annotation_AnnotationTypeMismatchException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_annotation_AnnotationTypeMismatchException$sub_nonrefs	java_lang_annotation_AnnotationTypeMismatchException;
};

// Object instance structure
struct _jc_java_lang_annotation_AnnotationTypeMismatchException$object {
	_jc_java_lang_annotation_AnnotationTypeMismatchException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_annotation_AnnotationTypeMismatchException$vtype	*vtype;
	_jc_java_lang_annotation_AnnotationTypeMismatchException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_annotation_AnnotationTypeMismatchException$vtype _jc_java_lang_annotation_AnnotationTypeMismatchException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_annotation_AnnotationTypeMismatchException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_annotation_AnnotationTypeMismatchException$class_object;

#endif	/* _JC_java_lang_annotation_AnnotationTypeMismatchException_H_ */
